iter_files

Function iter_files 

pub fn iter_files(cpio_binary: &[u8]) -> impl Iterator<Item = Entry<'_>>
Returns an iterator that iterates over each content of the given cpio file.

The iterator checks if the header of an entry is correct. If it is corrupt (e.g., wrong magic value), the iterator stops iterating.